/* 
 * This File is part of the iowj-project   
 * $Id: I2C.java,v 1.3 2005/11/19 15:34:45 Thomas Wagner Exp $
 * Copyright (C)2005 by Thomas Wagner
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.wagner_ibw.iow;

import java.util.Vector;

/**
 * This is the implementation of the I2C special mode function.
 * <p><b>(unfinished!)</b></p>
 * @author Thomas Wagner
 */
public class I2C implements SpecialModeFunction {

	/**
	 * Name of this special mode function.
	 */
	final static String name = "I2C";
	
	/**
	 * Reference to the underlying IOW device.
	 */
	private IowInterface iow;
	
	Vector devices;


	/**
	 * Constructor
	 */
	public I2C(){
		devices = new Vector();
	}
	
	public void addI2CDevice(I2CDevice dev){
		if (!devices.contains(dev)) {
			devices.add(dev);
			dev.setIowDevice(iow);
		}
	}

	public void removeI2CDevice(I2CDevice dev) {
		if (devices.contains(dev)) {
			devices.remove(dev);
			dev.setIowDevice(null);
		}
	}
	
	/**
	 * Returns Information about this LM75 as String.
	 * @return String representation of information obout this LM75
	 * (slave address, temperatures, ...).
	 */
	public String toString(){
		StringBuffer sb = new StringBuffer();
		sb.append("I2C[");
		for (int i = 0; i < devices.size(); i++) {
			I2CDevice dev = (I2CDevice)devices.get(i);
			String name = dev.getName();
			int devClass = dev.getI2cClass();
			int address = dev.getI2cAddress();
			sb.append(name);
			sb.append("[");
			sb.append(devClass);
			sb.append("/");
			sb.append(address);
			sb.append("]");
		}
/*		
		sb.append("LM75:");
		sb.append("SlaveAddress[");
		sb.append(devAdr);
		sb.append("],tCurr[");
		sb.append(tCurrent);
		sb.append("],tOs[");
		sb.append(tOs);
		sb.append("],tHyst[");
		sb.append(tHyst);
		*/
		sb.append("]");
		
		return sb.toString();
	}
	
	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#getDisableReport()
	 */
	public int[] getDisableReport() {
		int wbuf[] = {1,0,0,0,0,0,0,0};
		return wbuf;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#getEnableReport()
	 */
	public int[] getEnableReport() {
		int wbuf[] = {1,1,0,0,0,0,0,0};
		return wbuf;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#getIow24SpecialBits()
	 */
	public int[] getIow24SpecialBits() {
		int masks[] = {0x06};
		return masks;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#getIow40SpecialBits()
	 */
	public int[] getIow40SpecialBits() {
		int masks[] = {0xc0};
		return masks;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#getReportIds()
	 */
	public int[] getReportIds() {
		int ids[] = {0x02,0x03};
		return ids;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#getSpecialModeFuncionId()
	 */
	public int getSpecialModeFuncionId() {
		return SpecialModeFunction.SMF_I2C_ID;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#matchReportId(int)
	 */
	public boolean matchReportId(int reportId) {
		return ((reportId == 0x02) || (reportId == 0x03));
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#reportReceived(int[])
	 */
	public void reportReceived(int[] readBuffer) {
		for (int i = 0; i < devices.size(); i++) {
			((I2CDevice)devices.get(i)).reportReceived(readBuffer);
		}
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#setIowDevice(de.wagner_ibw.iow.IowInterface)
	 */
	public void setIowDevice(IowInterface iow) {
		this.iow = iow;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#checkCompatibility()
	 * @since 0.9.4
	 */
	public boolean checkCompatibility(int id, int rev, int specialModes) {
		// TODO Auto-generated method stub
		return true;
	}

	/* (non-Javadoc)
	 * @see de.wagner_ibw.iow.SpecialModeFunction#getName()
	 */
	public String getName() {
		return name;
	}

}
