/*
 * This File is part of the iowj-project   
 * $Id: I2CAddress.java,v 1.3 2005/07/14 19:11:21 Thomas Wagner Exp $
 * Copyright (C)2004 by Thomas Wagner
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package de.wagner_ibw.iow;

/**
 * This class represents a i2c slave address. It contains the 
 * group 1 part (4 bit, further called 'device class') and the group 2
 * part (3 bit, further called device address) of the slave address.
 * @author Thomas Wagner
 */
public class I2CAddress {
	int deviceClass;
	int deviceAddress;
	int slaveAddress;
	
	public I2CAddress(int deviceClass, int deviceAddress){
		this.deviceClass = deviceClass;
		this.deviceAddress = deviceAddress;
		slaveAddress = deviceClass << 4 | deviceAddress << 1;
	}
	
	public int getReadAddress(){
		return slaveAddress | 0x01;	//set bit0
	}
	
	public int getWriteAddress(){
		return slaveAddress & 0xfe; //clear bit0
	}
	
	public String toString(){
		return deviceClass + "/" + deviceAddress;
	}

}
