/* 
 * This File is part of the iowj-project   
 * $Id$
 * Copyright (C)2005 by Thomas Wagner
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
package de.wagner_ibw.iow;

/**
 * This class represents a single switch matrix event, received by an IOW 40.
 * @author Thomas Wagner
 * @since 0.9.4
 */
public class SwitchMatrixEvent {

	private int row;
	private int col;
	private int[] oldMatrix = {0,0,0,0,0,0,0,0};;
	private int[] newMatrix = {0,0,0,0,0,0,0,0};;
			
	public SwitchMatrixEvent(int[] newMatrix, int[] oldMatrix) {
		for(int i = 0; i < 8; i++) {
			this.newMatrix[i] = newMatrix[i];
			this.oldMatrix[i] = oldMatrix[i];
			
			if( newMatrix[i] != 0) {
				row = i + 1;
				if(newMatrix[i] == 0x1 )
					col = 1;
				else if(newMatrix[i] == 0x2 )
					col = 2;
				else if(newMatrix[i] == 0x4 )
					col = 3;
				else if(newMatrix[i] == 0x8 )
					col = 4;
				else if(newMatrix[i] == 0x10 )
					col = 5;
				else if(newMatrix[i] == 0x20 )
					col = 6;
				else if(newMatrix[i] == 0x40 )
					col = 7;
				else if(newMatrix[i] == 0x80 )
					col = 8;
			}
		}
	}
	
	public int getRow() {
		return row;
	}
	
	public int getCol() {
		return col;
	}
	
	public String toString() {
		StringBuffer sb = new StringBuffer();
		sb.append("SwitchMatrix[Row[");
		sb.append(row);
		sb.append("],Col[");
		sb.append(col);
		sb.append("]]");
		sb.append("\tSMXnew[");
		for (int i = 7; i > -1; i--) {
			sb.append(newMatrix[i]);
			if(i > 0)
				sb.append(",");
			else	
				sb.append("]");
		}
		sb.append("\tSMXold[");
		for (int i = 7; i > -1; i--) {
			sb.append(oldMatrix[i]);
			if(i > 0)
				sb.append(",");
			else	
				sb.append("]");
		}
		return sb.toString();
	}

	/**
	 * @return
	 */
	public int[] getNewMatrix() {
		return newMatrix;
	}

	/**
	 * @return
	 */
	public int[] getOldMatrix() {
		return oldMatrix;
	}

}
